<?php
/**
 * Plugin CIWIDGET
 * Copyright (c) Christophe IMBERTI
 * Licence Creative commons by-nc-sa
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

include_spip('inc/widget_commun');
include_spip('inc/config');

function formulaires_ciwidget_gis_charger_dist($objet = '', $id_objet = '', $id_widget = 0, $retour = '') {
    	$id_auteur = isset($GLOBALS['visiteur_session']['id_auteur']) ? $GLOBALS['visiteur_session']['id_auteur'] : 0;

	if (!autoriser('modifier',$objet,$id_objet) AND $id_objet!=(0-$id_auteur))
		return false;

        $valeurs = array(
            'titre'=>'',
            'descriptif'=>'',
            'lat'=>lire_config('gis/lat'),
            'lon'=>lire_config('gis/lon'),
            'zoom'=>lire_config('gis/zoom'),
            'typecarte'=>'point_libre',
            'numero'=>'',
            'largeur'=>'100',
            'hauteur'=>'400',
            'fondcarte'=>'plan'
            );
        
        $id_widget = intval($id_widget);
	if ($id_widget>0) {
		$result = sql_select("*", "spip_ciwidget", "id_widget=$id_widget");
		while ($row = sql_fetch($result)) { 
			$valeurs = $row;
		}
                
                // anti hack
                if (isset($valeurs['type_widget']) AND $valeurs['type_widget']!='gis'){
                    return false;
                }
                
                // unserialize le champ contenu
                if (isset($valeurs['contenu'])){
                    $contenu = unserialize($valeurs['contenu']);
                    $valeurs['contenu'] = '';
                    if ($contenu AND is_array($contenu)){
                        $valeurs = array_merge($valeurs,$contenu);
                    }
                }
	}

        $valeurs['retour_objet'] = ciwidget_retour_vers_objet($objet, $id_objet);

	return $valeurs;
}

function formulaires_ciwidget_gis_verifier_dist($objet = '', $id_objet = '', $id_widget = 0, $retour = '') {
        $erreurs = array();
        
	$titre = _request('titre');	
	if (!$titre){
		$erreurs['titre'] = _T('info_obligatoire');
        }
        
	$lat = _request('lat');	
	if (!$lat){
		$erreurs['lat'] = _T('info_obligatoire');
        } elseif (!is_numeric($lat)) {
		$erreurs['lat'] = _T('ciwidget:valeur_incorrecte');
        }

	$lon = _request('lon');	
	if (!$lon){
		$erreurs['lon'] = _T('info_obligatoire');
        } elseif (!is_numeric($lon)) {
		$erreurs['lon'] = _T('ciwidget:valeur_incorrecte');
        }

	$zoom = _request('zoom');	
	if (!$zoom){
		$erreurs['zoom'] = _T('info_obligatoire');
        } elseif (!intval($zoom)) {
		$erreurs['zoom'] = _T('ciwidget:valeur_incorrecte');
        }

        $typecarte = _request('typecarte');
        $numero = _request('numero');
        $tableau_typecarte = ciwidget_gis_typecarte();
        $typecarte_possibles = array_keys($tableau_typecarte);
        if (!in_array($typecarte,$typecarte_possibles)){
		$erreurs['typecarte'] = _T('ciwidget:valeur_incorrecte');
        } elseif (isset($tableau_typecarte[$typecarte]['id_critere']) AND $tableau_typecarte[$typecarte]['id_critere']){
                if (!intval($numero)) {
                        $erreurs['numero'] = _T('ciwidget:valeur_incorrecte');
                }
        }
        
        if (intval(_request('largeur'))>100) {
                $erreurs['largeur'] = _T('ciwidget:valeur_incorrecte');
        }
        if (intval(_request('largeur'))<10) {
                $erreurs['largeur'] = _T('ciwidget:valeur_incorrecte');
        }
        
	if (ciwidget_erreur_hauteur(_request('hauteur'))){
            $erreurs['hauteur'] = ciwidget_erreur_hauteur(_request('hauteur'));
        }	

        $fondcarte = _request('fondcarte');
        $fondcarte_possibles = array('plan','photo','choix');
        if (!in_array($fondcarte,$fondcarte_possibles)){
		$erreurs['fondcarte'] = _T('ciwidget:valeur_incorrecte');
        }

	return $erreurs;
}

function formulaires_ciwidget_gis_traiter_dist($objet = '', $id_objet = '', $id_widget = 0, $retour = '') {
        $id_widget = intval($id_widget);
        $res = array();
        
        $c = array();
	foreach (array('titre', 'descriptif') as $champ){
		$c[$champ] = _request($champ);
        }
        
        $lat = _request('lat');
        $lon = _request('lon');
        $zoom = _request('zoom');
        $typecarte = _request('typecarte');
        $numero = _request('numero');
        $largeur = _request('largeur');
        $hauteur = _request('hauteur');
        $fondcarte = _request('fondcarte');
        
        $c['contenu'] = serialize(array('lat'=>$lat, 'lon'=>$lon, 'zoom'=>$zoom,
            'typecarte'=>$typecarte, 'numero'=>$numero,
            'largeur'=>$largeur, 'hauteur'=>$hauteur,
            'fondcarte'=>$fondcarte));
        $c['type_widget'] = 'gis';
        $c['objet'] = $objet;
        $c['id_objet'] = $id_objet;
        
	if ($id_widget>0) {
            // modifier
            sql_updateq("spip_ciwidget", $c, "id_widget=$id_widget");
        } else {
            // ajouter
            $id_widget = sql_insertq('spip_ciwidget', $c);
        }
    
        $res['redirect'] = ciwidget_retour_vers_objet($objet, $id_objet);

	return $res;
}

function ciwidget_choisir_typecarte($nom_element='',$cle_element='',$disabled=''){
    $return = '';
    $selected = '';
    $disabled_texte = '';
    if ($disabled){
        $disabled_texte = 'disabled="disabled"';
    }
    if (!$cle_element){
        $cle_element = 'point_libre';
    }
    
    // tableau des valeurs
    $tableau_valeurs = ciwidget_gis_typecarte();
    // Parcours du tableau
    $return .= '<select name="'.$nom_element.'" id="'.$nom_element.'" '.$disabled_texte.'>';
    foreach($tableau_valeurs as $cle=>$valeur){
        
        if($cle == $cle_element){
            $selected = ' selected="selected"';
        } else {
            $selected = '';
        }
        
        // Affichage de la ligne
        $return .= "\t".'<option value="'. $cle .'"'. $selected . '>'. _T('ciwidget:gis_typecarte_'.$cle) .'</option>'."\n";
    }
    $return .= '</select>'."\n";

    return $return;
}

?>