<?php
/**
 * Plugin CIWIDGET
 * Copyright (c) Christophe IMBERTI
 * Licence Creative commons by-nc-sa
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

include_spip('inc/widget_commun');
include_spip('inc/ciwidget_tmp');
include_spip('inc/ciwidget_graphique');
include_spip('inc/ciwidget_importer');
include_spip('inc/filtres_boites');


function formulaires_ciwidget_tableau6_charger_dist($objet = '', $id_objet = '', $id_widget = 0, $id_widget_tmp = 0, $retour = '') {
	if (!$id_widget_tmp){
		return false;
        }

        $valeurs = ciwidget_valeurs_tmp($id_widget,$id_widget_tmp,'tableau');
        
        // securite
	if (!isset($valeurs['objet']) OR !isset($valeurs['id_objet']) OR !isset($valeurs['id_auteur']) 
                OR !autoriser('modifier',$valeurs['objet'],$valeurs['id_objet'])
                OR $valeurs['id_auteur']!=$GLOBALS['visiteur_session']['id_auteur']){
		return false;
        }

        if ($id_widget>0){
            $valeurs_persistantes = ciwidget_valeurs_lues_en_base($id_widget,'tableau');
        } else {
            $valeurs_persistantes = array();
        }
        
        $contenus_date = array(
            'import_auto_date_premier'=>'Y-m-d',
            'import_auto_date_dernier'=>'d/m/Y H:i:s',
        );
        
        // afficher les timestamp au format date
        foreach ($contenus_date AS $cle=>$format){
            if (isset($valeurs[$cle]) AND $valeurs[$cle]){
                if ($id_widget>0 
                        AND isset($valeurs_persistantes[$cle]) AND $valeurs_persistantes[$cle] 
                        AND $valeurs_persistantes[$cle]>$valeurs[$cle]){
                    $valeurs[$cle] = date($format,$valeurs_persistantes[$cle]);
                } else {
                    $valeurs[$cle] = date($format,$valeurs[$cle]);
                }   
            }
        }

        if (!isset($valeurs['import_auto_url'])){
            $valeurs['import_auto_url'] = '';
        }

        $valeurs['importer_maintenant'] = 'non';
/*        
        if (!isset($valeurs['donnees']) OR !$valeurs['donnees']){
            $valeurs['importer_maintenant'] = 'oui';
        }
*/        
        $valeurs['retour_objet'] = ciwidget_retour_tmp_vers_objet($id_widget_tmp,$objet,$id_objet,$valeurs);
        
	return $valeurs;
}

function formulaires_ciwidget_tableau6_verifier_dist($objet = '', $id_objet = '', $id_widget = 0, $id_widget_tmp = 0, $retour = '') {
    $erreurs = array();
    $tableau_extensions = array('xlsx','csv');

    if (isset($_POST['suivant'])){
        if (_request('import_auto_active')=='oui' OR _request('importer_maintenant')=='oui'){

            $champs_obligatoires = array('import_auto_url','import_auto_date_premier','import_auto_delai','import_auto_delai_unite');            
            foreach ($champs_obligatoires AS $champ){
                if (!_request($champ)){
                        $erreurs[$champ] = _T('info_obligatoire');
                }
            }

            if (!$erreurs){
                
                $date_premier = _request('import_auto_date_premier'); 
                if ($date_premier){
                    list($annee, $mois, $jour) = explode('-', $date_premier);
                    if(!checkdate($mois,$jour,$annee)){
                        $erreurs['import_auto_date_premier'] =  _T('ciwidget:valeur_incorrecte');
                    }
                }

                if (_request('import_auto_delai')
                        AND !intval(_request('import_auto_delai'))>0){
                    $erreurs['import_auto_delai'] =  _T('ciwidget:valeur_incorrecte');
                }
                
                if (_request('import_auto_delai_unite') 
                        AND !in_array(_request('import_auto_delai_unite'),array('month','day','hour','minute'))){
                    $erreurs['import_auto_delai_unite'] =  _T('ciwidget:valeur_incorrecte');
                }
            }
            
            if (!$erreurs){
                $path = _request('import_auto_url');
                if (!tester_url_absolue($path)) {
                        return _T('medias:erreur_chemin_distant', array('nom' => $path));
                } else {
                    $extension = ciwidget_extension_tableau_distant($path,$tableau_extensions);
                    if (!in_array(strtolower($extension),$tableau_extensions) ){
                        $erreurs['url'] = _T('medias:erreur_upload_type_interdit',array('nom' => $path));
                    }
                }
            }
        }
    }

    return $erreurs;
}

function formulaires_ciwidget_tableau6_traiter_dist($objet = '', $id_objet = '', $id_widget = 0, $id_widget_tmp = 0, $retour = '') {
        refuser_traiter_formulaire_ajax();    

        include_spip('inc/distant');
        
        $type_widget = 'tableau';
        $c = array();
        $contenu_nouveau = array();
        
        $contenus = array(
            'import_auto_active',
            'import_auto_url',
            'import_auto_delai',
            'import_auto_delai_unite'
        );
        
        foreach ($contenus AS $contenu){
            $contenu_nouveau[$contenu] = _request($contenu);
        }
        
        // Convertir import_auto_date_premier en timestamp
        $date_premier = _request('import_auto_date_premier');
        if ($date_premier) {
            list($annee, $mois, $jour) = explode('-', $date_premier);
            $contenu_nouveau['import_auto_date_premier'] = mktime(0, 0, 0, $mois, $jour, $annee);
        }
        
        $id_widget_tmp = ciwidget_maj_tmp($id_widget,$id_widget_tmp,$c,$contenu_nouveau);

        if (_request('importer_maintenant')=='oui'){
            ciwidget_tableau_importer($id_widget_tmp,true,true);            
        }
        
        $res = ciwidget_retour_formulaire_etape($objet,$id_objet,$id_widget,$id_widget_tmp,$type_widget,3);

	return $res;
}

function ciwidget_tableau_choix_delai_unite($nom_element='',$valeur_element='',$onchange=false){
    $tableau_valeurs = array();
    foreach (array('month','day','hour','minute') AS $valeur){
        $tableau_valeurs[$valeur] = _T('ciwidget:'.$valeur);
    }
    $options = 'style="float:left;width:25%;"';
    return ciwidget_graphique_choix($nom_element,$valeur_element,$tableau_valeurs,$onchange,$options);
}

?>